Business Combinations - Purchase Price Allocation
=================================================

Purchase price allocation and intangible useful lives for acquisitions and mergers.

.. automodule:: calcbench.business_combinations
    :members:
    :undoc-members: